[![Tests](https://github.com/OneraHub/smoot/workflows/Tests/badge.svg)](https://github.com/OneraHub/smoot/actions?query=workflow%3ATests)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

# smoot

Surrogate-based Multi-Objective Optimization Tool.
